![pypi version 0.1.14](https://img.shields.io/badge/pypi-v0.1.14-orange.svg)
![python version 3.6](https://img.shields.io/badge/python-3.6-blue.svg)
![aiohttp version 3.x.x](https://img.shields.io/badge/aiohttp-3.x.x-blue.svg)
![build passing](https://img.shields.io/badge/build-passing-brightgreen.svg) 
![circleci passing](https://img.shields.io/badge/circleci-passing-brightgreen.svg)
![docs passing](https://img.shields.io/badge/docs-passing-brightgreen.svg)
![codecov](https://codecov.io/gh/grking8/aiostorage/branch/master/graph/badge.svg)
![license MIT](https://img.shields.io/badge/License-MIT-blue.svg)


## Summary

**aiostorage** is a Python library for performing common object storage 
operations asynchronously.

It currently supports the following object storage providers:

- [Backblaze B2 Cloud Storage](https://www.backblaze.com/b2/cloud-storage.html)

## Installation

aiostorage is available on [PyPI](https://pypi.python.org/pypi/aiostorage/) and can be installed in the usual way `pip install aiostorage`.

## Dependencies

- [aiohttp](https://aiohttp.readthedocs.io/en/stable/): 3.x.x

## Contributing

Follow these [Python open source contribution guidelines.](https://guyrking.com/2018/03/18/open-source-python-with-github-and-conda.html)

## Documentation

- [Code](http://aiostorage.readthedocs.io/)
- [Wiki](https://family-guy.github.io/aiostorage-wiki/)

## License

[MIT](http://opensource.org/licenses/MIT)
